<?php
/**
 * Alkivia Chameleon.
 * General functions for actions, filters anjd complementary functions.
 * 
 * @version		$Rev: 123 $
 * @author		Jordi Canals
 * @package		Themes
 * @subpackage	Chameleon
 * @link		http://alkivia.org/chameleon
 * @license		http://www.gnu.org/licenses/gpl.html GNU General Public License v3
 
	Copyright 2009 Jordi Canals <gpl@alkivia.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

define ('CHAM_ABSPATH', dirname(__FILE__));

/**
 * Sets the menu for theme settings.
 * 
 * @hook action 'admin_menu'
 * @return void
 */
function _cham_settings_menu() {
		add_theme_page(__('Customize Chameleon Theme', 'tx_themes'), 'Chameleon', 'edit_themes', 'chameleon', '_cham_settings_page');
}
add_action('admin_menu', '_cham_settings_menu');

/**
 * Loads the settings page in Dashboard.
 * 
 * @hook add_theme_page
 * @return void
 */
function _cham_settings_page() {
	global $cham_settings;
	
	include ( dirname(__FILE__) .'/settings.php' );
}

/**
 * Sets the favorites icon for blog and admin pages.
 * 
 * @hook action 'wp_head' and 'admin_head'
 * @return void
 */
function _cham_favicon() {
	echo '<link rel="shortcut icon" href="'
		. apply_filters('chameleon_favicon_url', get_bloginfo('template_directory') . '/images/favicon.ico')
		. '" />'; 
}

/**
 * Disables self pings.
 * This will disabloe sending pings to our own blog.
 * 
 * @author	Michael D. Adams
 * @link 	http://blogwaffe.com/2006/10/04/421/
 * @version	0.2
 * @hook action 'pre_ping'
 * @param array $links	Link list of URLs to ping.
 */
function _cham_disable_self_ping( &$links ) {
	$home = get_option( 'home' );
	foreach ( $links as $l => $link )
		if ( 0 === strpos( $link, $home ) )
			unset($links[$l]);
}

/**
 * Sets the styles for the WordPress Gallery.
 * As styles are included in CSS files, here we just start the DIV for gallery.
 * 
 * @hook filter 'gallery_style'
 * @param string $style	Default WordPress styles
 * @return string		New theme styles
 */
function _cham_gallery_style( $style ) {
	return '<div class="gallery">';
}
add_filter('gallery_style', '_cham_gallery_style');

/**
 * Filter to disable the default stylesheet for Alkivia plugins.
 * The styles needed are included in the theme style, so don't need to load them again.
 * 
 * @hook filter '{pluginID}_style_url
 * @param $url		Default stylesheed url
 * @return string	An empty string as URL to disable the default style.
 */
function _cham_disable_alkivia_styles( $url ) {
	return '';
}
add_filter('akucom_style_url', '_cham_disable_alkivia_styles'); 
add_filter('pagelist_style_url', '_cham_disable_alkivia_styles'); 
add_filter('sideposts_style_url', '_cham_disable_alkivia_styles');

/**
 * Filter to change the user theme style.
 * If settingts allow users to change settings.
 *
 * @hook filter 'chameleon_style_url'
 * @param string $palette Current style url
 * @return string New palette url
 */
function _cham_user_palette( $palette ) {
	if ( isset($_GET['theme-style']) && file_exists(dirname(__FILE__) . '/styles/' . strtolower($_GET['theme-style']) . '.css') ) {
		$style = strtolower($_GET['theme-style']);
	} elseif ( isset($_COOKIE['chameleon-style']) && file_exists(dirname(__FILE__) . '/styles/' . strtolower($_COOKIE['chameleon-style']) . '.css') ) {
		$style = strtolower($_COOKIE['chameleon-style']);
	} else {
		$settings = get_option('chameleon_settings');
		$style = $settings['style'];
	}
	setcookie('chameleon-style', $style, time() + 3600, '/');
	
	$palette = get_bloginfo('template_directory') . "/styles/{$style}.css";
	return $palette;
}

/**
 * Redirects user to a new page.
 * This is done if the custom field 'redirect' is defined as:
 * 		+ Filed Name:	redirect
 * 		+ Field Value:	New target URL.
 * 
 * @return void
 */
function cham_redirect() {
	global $post;
		
	if ( is_page() || is_single() ) {
		if ( $meta = get_post_meta($post->ID, 'redirect', true) ) {
			wp_redirect($meta, 301);
			exit;
		}
	}
}

/**
 * Creates the header menu bar based on settings.
 * 
 * @uses apply_filters() Calls the 'chameleon_pages_menu' hook on the menu page list.
 * @uses apply_filters() Calls the 'register' hook on register/admin item.
 * @uses apply_filters() Calls the 'loginout' hook on login/logout item.
 * @return string HTML formated menu bar.
 */
function cham_menubar() {
	$settings = get_option('chameleon_settings');
	
	$menu = '<ul>';
	
	if ( $settings['home_link'] ) {
		$menu .= '<li><a href="'. get_bloginfo('home') .'" title="'. get_bloginfo('name') .'">'. __('Home', 'chameleon') .'</a></li>'; 
	}
	$menu .= apply_filters('chameleon_pages_menu', wp_list_pages('title_li=&depth=1&echo=0'));

	if ( $settings['admin_link'] ) {
		// WP-REGISTER
		if ( is_user_logged_in() ) {
			$link = '<li><a href="' . admin_url() . '">' . __('Site Admin', 'chameleon') . '</a></li>';
		} else {
			if ( get_option('users_can_register') ) {
				$link = '<li><a href="' . site_url('wp-login.php?action=register', 'login') . '">' . __('Register', 'chameleon') . '</a></li>';
			}
		}
		$menu .= apply_filters('register', $link);
	}
	
	if ( $settings['login_link'] ) {
		// WP_LOGINOUT
		if ( is_user_logged_in() ) {
			$link = '<a href="' . wp_logout_url() . '">' . __('Log out', 'chameleon') . '</a>';
		} else {
			$link = '<a href="' . wp_login_url() . '">' . __('Log in', 'chameleon') . '</a>';
		}
		$menu .= '<li>'. apply_filters('loginout', $link) .'</li>';
	}
	$menu .= '</ul>';
	
	return $menu;
}

/**
 * Returns the footer text defined in Chameleon Settings.
 * 
 * @return string Footer text.
 */
function cham_get_footer() {
	$settings = get_option('chameleon_settings');
	return str_replace("\n", '<br />', $settings['footer']) . '<br />'; 
}

/**
 * Sets all actions and filters to configure the Chameleon Theme.
 * 
 * @return void
 */
function cham_configure() {
	global $cham_theme_data;
	
	$settings = get_option('chameleon_settings');

	if ( $settings['favicon'] ) {
		add_action('wp_head', '_cham_favicon');
		add_action('admin_head', '_cham_favicon');
	}
	if ( ! $settings['self_ping'] ) {
		add_action( 'pre_ping', '_cham_disable_self_ping' );
	}
	if ( $settings['switch_styles'] && ! is_admin() ) {
		add_filter('chameleon_palette_url', '_cham_user_palette');
	}
}

/**
 * Loads palette style.
 * 
 * @uses apply_filters() Calls 'chameleon_palette_url' on the palette url.
 * @return void
 */
function cham_load_palette() {
	global $cham_theme_data;
	
	if ( is_admin() ) {
		$url = get_bloginfo('template_directory') . '/admin.css';
	} else {
		$settings = get_option('chameleon_settings');
		$url = apply_filters('chameleon_palette_url', get_bloginfo('template_directory') . "/styles/{$settings['style']}.css");
	}
	wp_register_style('chameleon', $url, false, $cham_theme_data['Version']);
	wp_enqueue_style('chameleon');
}

/**
 * Installs the theme and creates all settings for Chameleon.
 * 
 * @return void
 */
function chameleon_install() {
	global $cham_theme_data;
	
	// Theme Defaults
	$settings = array(
			'style' => 'cafe',
			'favicon' => '1',
			'self_ping' => '0',
			'page_comments' => '0',
			'header' => 'solid',
			'home_link' => '1',
			'login_link' => '1',
			'admin_link' => '1',
			'sidebar-pos' => 'right',
			'switch_styles' => '0', 
			'footer' => '&copy; '. __('Copyright', 'chameleon') . date(' Y ') . get_bloginfo('name') .'. '. __('Some rights reserved.', 'chameleon')
			);
	
	// Save options
	add_option('chameleon_settings', $settings);
	add_option('chameleon_version', $cham_theme_data['Version']);
}

/**
 * Updates theme Options. Used when adding new options to theme.
 * 
 * @return void
 */
function chameleon_update() {
	global $cham_settings, $cham_theme_data;
	
	$ver = get_option('chameleon_version');
	if ( version_compare($ver, '0.7.2', '<') ) {
		$cham_settings['self_ping'] = '0';
		$cham_settings['page_comments'] = '0';
		
		update_option('chameleon_settings', $cham_settings);
	}
	// Save options
	// update_option('chameleon_settings', $cham_settings);
	update_option('chameleon_version', $cham_theme_data['Version']);
}

/**
 * Draws the posts navigator bar
 * 
 * @param string $class CSS class style
 */
function cham_post_navigator( $class = '' ) {
	global $posts;
	
	$naviclass = ( empty($class) ) ? 'navigator' : "navigator {$class}"; 
	
	if ( is_single () ) { ?>
		<div class="<?php echo $naviclass; ?>">
			<div class="navleft"><?php previous_post_link('&laquo; %link') ?></div>
			<div class="navright"><?php next_post_link('%link &raquo;') ?></div>
		</div>
	<?php } elseif ( function_exists('wp_pagenavi') ) {
		echo '<div class="pagenavi_container">';
		wp_pagenavi();
		echo '</div>';
	} else {
		global $wp_query;
		if ( $wp_query->found_posts > get_option('posts_per_page') || is_paged()) { 
		?>
			<div class="<?php echo $naviclass; ?>">
				<div class="navleft"><?php next_posts_link('&laquo; ' . __('Older Posts', 'chameleon')) ?></div>
				<div class="navright"><?php previous_posts_link(__('Newer Posts', 'chameleon') . ' &raquo;'); ?></div>
			</div>
		<?php } ?>
	<?php }
}

// ------------------------ END FUNCTIONS. START PROCESSING --------------

load_theme_textdomain('chameleon', CHAM_ABSPATH . '/lang');

global $cham_theme_data, $cham_settings;
$cham_theme_data = get_theme_data(dirname(__FILE__) . '/style.css');	// Read data from style.css file.
$cham_settings = get_option('chameleon_settings');			// Read Chameleon settings.

cham_configure();
cham_load_palette();

// Register the sidebars
if ( function_exists('register_sidebars') ) {
	register_sidebar(array( 'name' => __('Narrow Left', 'chameleon') ) );
	register_sidebar(array( 'name' => __('Narrow Right', 'chameleon') ) );
	
	register_sidebar(array( 'name'=> __('Wide Top', 'chameleon') ) );
	register_sidebar(array( 'name'=> __('Wide Bottom', 'chameleon') ) );
}

if ( empty($cham_settings) || ! is_array($cham_settings)) {	// Check the theme is installed or is new version
	chameleon_install();
}
if ( $cham_theme_data['Version'] != get_option('chameleon_version') ) {
	chameleon_update();
}

?>